<?php

namespace Drupal\cmlmigrations\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\cmlapi\Controller\GetCml;
use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Controller routines for page example routes.
 */
class StatusPage extends ControllerBase {

  /**
   * Page.
   */
  public function page() {
    $form = ['#markup' => ""];
    $migrations = Helper::getMigrations();
    $output = "<h3>Актуальный обмен</h3>";
    $now = DrupalDateTime::createFromTimestamp(REQUEST_TIME);
    if ($cml = GetCml::actual()) {
      $created = DrupalDateTime::createFromTimestamp($cml->created->value);
      $changed = DrupalDateTime::createFromTimestamp($cml->changed->value);
      $id = $cml->id();
      $output .= "&mdash; [{$id}] - ";
      $output .= $cml->field_status->value;
      $output .= " / Ago: ";
      $output .= $changed->diff($now)->format('%H:%i:%s');
      $output .= " / Time: ";
      $output .= $changed->diff($created)->format('%H:%i:%s');
      $output .= "<br>";
    }
    else {
      $output .= "&mdash; <br>";
    }
    $output .= "<h3>Текущий обмен</h3>";
    if ($cml = GetCml::curent()) {
      $created = DrupalDateTime::createFromTimestamp($cml->created->value);
      $changed = DrupalDateTime::createFromTimestamp($cml->changed->value);
      $id = $cml->id();
      $output .= "&mdash; [{$id}] - ";
      $output .= $cml->field_status->value;
      $output .= " / Ago: ";
      $output .= $changed->diff($now)->format('%H:%i:%s');
      $output .= " / Time: ";
      $output .= $changed->diff($created)->format('%H:%i:%s');
      $output .= "<br>";
    }
    else {
      $output .= "&mdash; <br>";
    }
    $output .= "<h3>Следующий обмен</h3>";
    if ($cml = GetCml::next()) {
      $created = DrupalDateTime::createFromTimestamp($cml->created->value);
      $changed = DrupalDateTime::createFromTimestamp($cml->changed->value);
      $id = $cml->id();
      $output .= "&mdash; [{$id}] - ";
      $output .= $cml->field_status->value;
      $output .= "<br>";
    }
    else {
      $output .= "&mdash; <br>";
    }
    $output .= "<h3>Очередь обменов</h3>";
    if (!empty($cmllist = GetCml::list())) {
      foreach ($cmllist as $id => $cml) {
        $output .= "&mdash; [{$id}] - ";
        $output .= $cml->field_status->value;
        $output .= " / Date: ";
        $output .= format_date(REQUEST_TIME - $cml->created->value, 'custom', 'H:i:s');
        $output .= "<br>";
      }
    }
    else {
      $output .= "&mdash; <br>";
    }
    $rows = [];
    if ($migrations) {
      $output .= "<h3>Статус</h3>";
      if ($migrations['list']) {
        $output .= "Готов<br>";
      }
      else {
        $output .= "Занят<br>";
      }
      foreach ($migrations['list'] as $id => $migration) {
        $date_formatter = \Drupal::service('date.formatter');
        $last = 'N/A';
        if (is_numeric($migration['last'])) {
          $last = $date_formatter->format($migration['last'] / 1000, 'custom', 'dM H:i:s');
        }
        $rows[] = [
          'label' => $migration['label'],
          'status' => $migration['status'],
          'total' => $migration['total'],
          'imported' => $migration['imported'],
          'unprocessed' => $migration['unprocessed'],
          'messages' => $migration['messages'],
          'last' => $last,
        ];
      }
      $form = \Drupal::formBuilder()->getForm('Drupal\cmlmigrations\Form\ExecMigrations', $migrations['list']);
    }

    return [
      'output' => ['#markup' => $output],
      'form' => $form,
      'migr-table' => [
        '#type' => 'table',
        '#header' => $this->buildHeader(),
        '#rows' => $rows,
      ],
    ];
  }

  /**
   * Header.
   */
  public function buildHeader() {
    $header = [
      'label' => $this->t('Migration'),
      'status' => $this->t('Status'),
      'total' => $this->t('Total'),
      'imported' => $this->t('Imported'),
      'unprocessed' => $this->t('Unprocessed'),
      'messages' => $this->t('Messages'),
      'last' => $this->t('Last'),
    ];
    return $header;
  }

}
