<?php

namespace Drupal\cmlmigrations\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\cmlmigrations\Controller\Service;

/**
 * Implements the form controller.
 */
class SettingsMigrations extends ConfigFormBase {

  /**
   * AJAX Responce.
   */
  public static function ajax($otvet) {
    $response = new AjaxResponse();
    $response->addCommand(new HtmlCommand("#exec-results", "<pre>{$otvet}</pre>"));
    return $response;
  }

  /**
   * AJAX ProdUuidFill.
   */
  public static function ajaxProdUuidFill(array $form, FormStateInterface $form_state) {
    $otvet = "ajaxProdUuidFill\n";
    $otvet .= Service::uuid1cFill();
    return self::ajax($otvet);
  }

  /**
   * AJAX ProdUuidRemove.
   */
  public static function ajaxProdUuidClear(array $form, FormStateInterface $form_state) {
    $otvet = "ajaxProdUuidClear\n";
    $otvet .= Service::uuid1cClear();
    return self::ajax($otvet);
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cmlmigrations_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['cmlmigrations.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cmlmigrations.settings');
    $form['mapping'] = [
      '#type' => 'details',
      '#title' => $this->t('Mapping'),
      '#open' => TRUE,
    ];
    $form['pipeline']['timeout'] = [
      '#title' => $this->t('Timeout'),
      '#type' => 'textfield',
      '#default_value' => $config->get('timeout'),
      '#description' => $this->t('Max migration time before failure (minute)'),
    ];
    $vocabulares = [];
    if (\Drupal::moduleHandler()->moduleExists('taxonomy')) {
      $vocabulares = taxonomy_vocabulary_get_names();
    }
    $form['mapping']['vocabulary'] = [
      '#title' => $this->t('Catalog Vocabulary'),
      '#type' => 'select',
      '#options' => $vocabulares,
      '#default_value' => $config->get('vocabulary'),
    ];
    $form['pipeline'] = [
      '#type' => 'details',
      '#title' => $this->t('Pipeline'),
    ];
    $form['pipeline']['timeout'] = [
      '#title' => $this->t('Timeout'),
      '#type' => 'textfield',
      '#default_value' => $config->get('timeout'),
      '#description' => $this->t('Max migration time before failure (minute)'),
    ];
    $form['product_uuid'] = [
      '#type' => 'actions',
      'fill' => [
        '#type' => 'submit',
        '#value' => 'Fill 1000 product_uuid field',
        '#ajax'   => [
          'callback' => '::ajaxProdUuidFill',
          'effect'   => 'fade',
          'progress' => ['type' => 'throbber', 'message' => ""],
        ],
      ],
      'remove' => [
        '#type' => 'submit',
        '#value' => 'Clear 1000 product_uuid field',
        '#ajax'   => [
          'callback' => '::ajaxProdUuidClear',
          'effect'   => 'fade',
          'progress' => ['type' => 'throbber', 'message' => ""],
        ],
      ],
      '#suffix' => '<div id="exec-results"></div>',
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * Implements form validation.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('cmlmigrations.settings');
    $timeout = trim($form_state->getValue('timeout'));
    if (!is_numeric($timeout)) {
      $timeout = 60;
    }
    $config
      ->set('vocabulary', $form_state->getValue('vocabulary'))
      ->set('timeout', $timeout)
      ->save();
  }

}
