<?php

namespace Drupal\cmlmigrations\Plugin\migrate\source;

use Drupal\cmlmigrations\MigrationsSourceBase;
use Drupal\cmlapi\Controller\CurrentXmlPath;
use Drupal\cmlapi\Xml\TovarParcer;
use Drupal\cmlmigrations\Controller\FindVariation;

/**
 * Source for CSV.
 *
 * @MigrateSource(
 *   id = "cml_commerce_product"
 * )
 */
class CommerceProduct extends MigrationsSourceBase {

  /**
   * {@inheritdoc}
   */
  public function getRows() {
    $k = 0;
    $rows = [];
    $source = FALSE;
    $variations = FALSE;
    $filepath = CurrentXmlPath::get('import');
    $source = TovarParcer::getRows($filepath);
    if ($source && isset($source['data']) && !empty($source['data'])) {
      if (count($source['data']) > 1000) {
        // Если вариаций много - грузим сразу все.
        $variations = FindVariation::getBy1cUuid();
      }
      foreach ($source['data'] as $id => $row) {
        if ($k++ < 100 || !$this->uipage) {
          $product = $row['product'];
          $offers = $row['offers'];
          $rows[$id] = [
            'uuid' => $id,
            'type' => 'default',
            'stores' => 1,
            'status' => 1,
            'title' => trim($product['Naimenovanie']),
            'catalog' => $product['Gruppy'][0],
            'changed' => REQUEST_TIME,
            'body_value' => FALSE,
            'body_format' => "wysiwyg",
          ];
          self::hasVariations($rows, $variations, $id);
          self::hasImage($rows, $product, $id);
        }
      }
    }
    $this->debug = TRUE;
    return $rows;
  }

  /**
   * HasVariations.
   */
  public function hasVariations(&$rows, $variations, $id) {
    $result = FALSE;
    if (!$variations) {
      // Ищем вариации текущего товара.
      $variations = FindVariation::getBy1cUuid($id, FALSE);
    }
    if (isset($variations[$id])) {
      $result = $variations[$id];
      $rows[$id]['variations'] = $result;
    }
    return $result;
  }

  /**
   * HasImage.
   *
   * TODO: LIKE-QUERY TOOO HARD.
   */
  public function hasImage(&$rows, $product, $id, $field = 'Kartinka') {
    $result = FALSE;
    if (isset($product[$field])) {
      $image = $product[$field];
      $query = \Drupal::entityQuery('file');
      $query->condition('uri', "%$image%", 'LIKE');
      $query->condition('status', 1);
      $query->sort('created', 'DESC');
      $fileIds = $query->execute();
      $fid = array_shift($fileIds);
      $rows[$id]['field_image'] = [
        'image' => $image,
        'target_id' => $fid,
      ];
    }
    return $result;
  }

}
